@@ -1,6 +1,7 @@
 #![no_std]
 #![allow(clippy::doc_markdown)]
 #![allow(clippy::inline_always)]
+#![allow(clippy::match_bool)]
 #![allow(incomplete_features)]
 #![feature(const_compare_raw_pointers)]
 #![feature(const_fn)]
@@ -215,7 +216,8 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// constant rather than a method.
   pub const CAPACITY: usize = N;
 
-  /// Returns the remaining capacity of the StaticVec.
+  /// Returns the remaining capacity (which is to say, `self.capacity() - self.len()`) of the
+  /// StaticVec.
   #[inline(always)]
   pub const fn remaining_capacity(&self) -> usize {
     N - self.length
@@ -278,14 +280,14 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// Returns a constant pointer to the first element of the StaticVec's internal array.
   #[inline(always)]
   pub const fn as_ptr(&self) -> *const T {
-    // Written like this so it can be `const fn`.
+    // Written like this so it can be a `const fn`.
     &self.data as *const MaybeUninit<[T; N]> as *const T
   }
 
   /// Returns a mutable pointer to the first element of the StaticVec's internal array.
   #[inline(always)]
   pub const fn as_mut_ptr(&mut self) -> *mut T {
-    // Written like this so it can be `const fn`.
+    // Written like this so it can be a `const fn`.
     &mut self.data as *mut MaybeUninit<[T; N]> as *mut T
   }
 
